@@ -19,13 +19,15 @@ if "__main__" == __name__:
         "password": "Lton2008@",
     })
 
-    print(">" * 30)
-    print(
-        zentao.user_task(
-            userID=1,
-            type="finishedBy"
-        )
+    response = zentao.user_task(
+        userID=1,
+        type="assignedTo",
+        # raw=True
     )
+
+    print(">" * 30)
+    # print(response)
+    print(response)
     print("<" * 30)
 
 # end
